package AirBomber;

import java.awt.*;
import java.util.Random;

public class BomberRenderer 
{
    private BomberEntity EntityBomber;

    private int _pictureWidth;
    private int _pictureHeight;

    private int _startPosX;
    private int _startPosY;

    private int _bomberWidth = 200;
    private int _bomberHeight = 200;

    public EngineRenderer EngineRenderer;

    public boolean Init(int Speed, double Weight, Color BodyColor, Color AdditionalColor, boolean FuelTanks, boolean Bombs, int Width, int Height)
    {
        if (Width < _bomberWidth || Height < _bomberHeight)
            return false;

        _pictureWidth = Width;
        _pictureHeight = Height;

        EntityBomber = new BomberEntity();
        EntityBomber.Init(Speed, Weight, BodyColor, AdditionalColor, FuelTanks, Bombs);
        
        EngineRenderer = new EngineRenderer();

        Random Random = new Random();
        EngineRenderer.SetAmount(Random.nextInt(1, 7));

        return true;
    }

    public BomberEntity GetEntityBomber() { return EntityBomber; }

    public void SetPosition(int x, int y)
    {
        if (EntityBomber == null)
            return;

        if (x < 0)
            x = 0;
        else if (x + _bomberWidth > _pictureWidth)
            x = _pictureWidth - _bomberWidth;
        
        _startPosX = x;

        if (y < 0)
            y = 0;
        else if (y + _bomberHeight > _pictureHeight)
            y = _pictureHeight - _bomberHeight;

        _startPosY = y;
    }

    public void MoveEntity(DirectionType Direction)
    {
        if (EntityBomber == null)
            return;

        switch (Direction)
        {
            case Up:
                if (_startPosY - EntityBomber.Step > 0)
                    _startPosY -= (int)EntityBomber.Step;

                break;

            case Down:
                if (_startPosY + _bomberHeight + EntityBomber.Step <= _pictureHeight)
                    _startPosY += (int)EntityBomber.Step;

                break;

            case Left:
                if (_startPosX - EntityBomber.Step > 0)
                    _startPosX -= (int)EntityBomber.Step;

                break;

            case Right:
                if (_startPosX + _bomberWidth + EntityBomber.Step <= _pictureWidth)
                    _startPosX += (int)EntityBomber.Step;

                break;
        }
    }

    public void DrawEntity(Graphics g)
    {
        if (EntityBomber == null)
            return;        

        /** Отрисовка основной части */
        g.setColor(EntityBomber.GetBodyColor());

        int[] LeftWingX = {
            _startPosX + 90,
            _startPosX + 100, 
            _startPosX + 108, 
            _startPosX + 90, 
        };
        int[] LeftWingY = {
            _startPosY, 
            _startPosY, 
            _startPosY + 85, 
            _startPosY + 85, 
        };
        g.drawPolygon(LeftWingX, LeftWingY, 4);


        int[] RightWingX = {
            _startPosX + 90,
            _startPosX + 100, 
            _startPosX + 108, 
            _startPosX + 90, 
        };
        int[] RightWingY = {
            _startPosY + 200, 
            _startPosY + 200, 
            _startPosY + 115, 
            _startPosY + 115, 
        };
        g.drawPolygon(RightWingX, RightWingY, 4);

        int[] BodyX = {
            _startPosX + 35,
            _startPosX + 200,
            _startPosX + 200,
            _startPosX + 35,
        };
        int[] BodyY = {
            _startPosY + 85,
            _startPosY + 85,
            _startPosY + 115,
            _startPosY + 115,
        };
        g.drawPolygon(BodyX, BodyY, 4);

        int[] NoseX = {
            _startPosX, 
            _startPosX + 35,
            _startPosX + 35,
        };
        int[] NoseY = {
            _startPosY + 100,
            _startPosY + 85,
            _startPosY + 115,
        };
        g.fillPolygon(NoseX, NoseY, 3);

        int[] BackLeftWingX = {
            _startPosX + 170,
            _startPosX + 200,
            _startPosX + 200,
            _startPosX + 170,
        };
        int[] BackLeftWingY = {
            _startPosY + 70,
            _startPosY + 40,
            _startPosY + 85,
            _startPosY + 85,
        };
        g.drawPolygon(BackLeftWingX, BackLeftWingY, 4);

        int[] BackRightWingX = {
            _startPosX + 170,
            _startPosX + 200,
            _startPosX + 200,
            _startPosX + 170,
        };
        int[] BackRightWingY = {
            _startPosY + 130,
            _startPosY + 160,
            _startPosY + 115,
            _startPosY + 115,
        };
        g.drawPolygon(BackRightWingX, BackRightWingY, 4);

        /** Отрисовка дополнительных элементов */
        g.setColor(EntityBomber.GetAdditionalColor());

        if (EntityBomber.GetFuelTanks())
        {
            int[] LeftGasTankX = {
                _startPosX + 50,
                _startPosX + 75,
                _startPosX + 75,
                _startPosX + 50,
            };
            int[] LeftGasTankY = {
                _startPosY + 85,
                _startPosY + 85,
                _startPosY + 70,
                _startPosY + 70,
            };
            g.fillPolygon(LeftGasTankX, LeftGasTankY, 4);

            int[] RightGasTankX = {
                _startPosX + 50,
                _startPosX + 75,
                _startPosX + 75,
                _startPosX + 50,
            };
            int[] RightGasTankY = {
                _startPosY + 115,
                _startPosY + 115,
                _startPosY + 130,
                _startPosY + 130,
            };
            g.fillPolygon(RightGasTankX, RightGasTankY, 4);
        }

        if (EntityBomber.GetBombs())
        {
            g.fillOval(_startPosX + 110, _startPosY + 115, 50, 25);
            g.fillOval(_startPosX + 110, _startPosY + 60, 50, 25);
        }

        EngineRenderer.DrawEngines(g, EntityBomber.GetBodyColor(), _startPosX, _startPosY);
    }
}
